FAQ
=================


    1. *Does tsfresh support different time series lengths?*
       Yes, it supports different time series lengths. However, some feature calculators can demand a minimal length
       of the time series. If a shorter time series is passed to the calculator, normally a NaN is returned.

